Glossary
========

.. glossary::

    array-like
        An object that can be interpreted as an array, including :class:`numpy.ndarray` and (nested) sequences. Any object accepted by :func:`numpy.array` is array-like.
